# Python Geometric Near-neighbor Access Tree (GNAT)

Python implementation of Geometric Near-neighbor Access Tree (GNAT) data structure as in OMPL to search nearest neighbors. It can be used to search nearest neighbors in complex space such as SE3.

## Please note

This project is no longer maintained given the fact that pure python implementation has a bad performance time. Instead, please use the python binding version of [GNAT](https://github.com/ZhuoyunZhong/gnat).
